# -*- coding: utf-8 -*-

from collective.excelexport.interfaces import IExportable


class IExtendedProjectExportable(IExportable):
    """
    """


class IUsersExportable(IExportable):
    """
    """
